@@ -355,7 +355,14 @@ gnome_print_job_setup_context (GnomePrintJob *job, GnomePrintContext *pc)
 	}
 
 	gnome_print_job_update_layout_data (job);
-	if (job->priv->LY_LIST) {
+	if (job->priv->LY_LIST && g_list_length (job->priv->LY_LIST) && 
+			!((g_list_length (job->priv->LY_LIST) == 1) &&
+				(((gdouble *) g_list_nth_data (job->priv->LY_LIST, 0)) [0] == 1.) &&
+				(((gdouble *) g_list_nth_data (job->priv->LY_LIST, 0)) [1] == 0.) &&
+				(((gdouble *) g_list_nth_data (job->priv->LY_LIST, 0)) [2] == 0.) &&
+				(((gdouble *) g_list_nth_data (job->priv->LY_LIST, 0)) [3] == 1.) &&
+				(((gdouble *) g_list_nth_data (job->priv->LY_LIST, 0)) [4] == 0.) &&
+				(((gdouble *) g_list_nth_data (job->priv->LY_LIST, 0)) [5] == 0.))) {
 		GnomePrintFilter *multipage;
 		GValue vd = {0,};
 		GValueArray *va = g_value_array_new (0);
